import java.awt.Frame;
import java.awt.Label;
import java.awt.Graphics;
import java.awt.Color;
import java.awt.BorderLayout;
import java.util.Vector;
import java.awt.event.*;

//We only use the stroke class here...
import com.aleax.gui.gesture.Stroke;

/**
 * Gesturing demo class.
 *
 * <p>Shows how to use gestures without using the GestureInterface.
 * The first stroke made will be the template that further strokes
 * are compared to. The label at the bottom shows if the strokes match.</p>
 *
 * @version 1.0 28 Apr 2001
 * @author Yiannis Paschalidis
 */ 
public final class SimpleRecognitionTest extends Frame implements MouseListener, MouseMotionListener
{
	private final Label statusLabel = new Label();
	private final Vector tempPoints = new Vector();
	private Stroke tempStroke = null;
	private Stroke templateStroke = null;

	/** Application entry point. */
	public static void main(String args[])
	{
		new SimpleRecognitionTest();
	}

	/** Creates a new SimpleRecognitionTest. */
	private SimpleRecognitionTest()
	{
		super("Stroke recognition demo");
		
		//Exit when the window closes
		addWindowListener
		(
			new WindowAdapter() 
			{
				public void windowClosing(WindowEvent we) { System.exit(0); }
			}
		);

		//Set up the panel
		setLayout(new BorderLayout());
		statusLabel.setText("Draw template stroke...");
		add(statusLabel,BorderLayout.SOUTH);

		setBounds(100, 100, getToolkit().getScreenSize().width - 200, getToolkit().getScreenSize().height - 200);
		setVisible(true);

		addMouseListener(this);
		addMouseMotionListener(this);
	}

	public void mouseClicked(MouseEvent me) {}
	public void mouseEntered(MouseEvent me) {}
	public void mouseExited(MouseEvent me) {}
	public void mouseMoved(MouseEvent me) {}

	public void mousePressed(MouseEvent me) 
	{
		tempPoints.clear();
		tempPoints.add(me.getPoint());
		tempStroke = null;

		repaint();
	}

	public void mouseDragged(MouseEvent me) 
	{
		tempPoints.add(me.getPoint());
		tempStroke = new Stroke(tempPoints);
		repaint();
	}
	
	public void mouseReleased(MouseEvent me) 
	{
		//Was it just a click, not a stroke?
		if (tempStroke==null)
		{
			return;
		}
		
		tempPoints.add(me.getPoint());
		
		if (templateStroke==null)
		{
			templateStroke = new Stroke(tempPoints);
			statusLabel.setText("Draw strokes to match the template...");
		}
		else
		{
			tempStroke = new Stroke(tempPoints);
			statusLabel.setText("Strokes match: " + templateStroke.equivalentTo(tempStroke));
		}

		repaint();
	}

	/** Overriden to show the template stroke and last stroke made. */
	public void paint(Graphics g)
	{
		super.paint(g);

		if (templateStroke != null)
		{
			g.setColor(Color.black);
			templateStroke.paint(g);
		}

		if (tempStroke != null)
		{
			g.setColor(Color.red);
			tempStroke.paint(g);
		}
	}
}