import java.awt.*;
import java.util.Vector;
import java.awt.event.*;
import java.io.*;

import com.aleax.gui.gesture.*;

/**
 * This is a simple example that shows how
 * to use the GestureInterface class.
 *
 * @version 1.0 28 Apr 2001
 * @author Yiannis Paschalidis
 */ 
public final class TextExample extends Frame implements ActionListener, GestureListener
{
	private static final String DATA_FILE_NAME = "textexample.dat";

	private final Label statusLabel = new Label();
	private final Button settingsButton = new Button("Edit settings");
	private final Button editButton = new Button("Edit gestures");

	private com.aleax.gui.gesture.Stroke lastStroke = null;

	/** Application entry point. */
	public static void main(String args[])
	{
		//Read in the current settings (if any)
		File f = new File(DATA_FILE_NAME);
		
		if (f.canRead())		
		{
			try
			{
				FileInputStream fis = new FileInputStream(f);
				GestureInterface.readSettings(fis);
				fis.close();
			}
			catch (Exception e)
			{
				System.out.println("ERROR: couldn't read in gesture settings: "+e);
				e.printStackTrace();
			}
		}
		else
		{
			//Okay, chances are that this is the first time this 
			//demo is being run, so set up the gestures...

			Vector v = new Vector();

			v.add(new Gesture(32, "(space)"));

			for (char letter = 'a' ; letter<='z' ; letter++)
			{
				v.add(new Gesture((int)letter, "Letter: "+letter));
			}
			
			for (char letter = 'A' ; letter<='Z' ; letter++)
			{
				v.add(new Gesture((int)letter,"Letter: "+letter));
			}
			
			for (char letter = '0' ; letter<='9' ; letter++)
			{
				v.add(new Gesture((int)letter,"Number: "+letter));
			}
			
			Gesture[] gestures = (Gesture[])v.toArray(new Gesture[v.size()]);
			GestureInterface.setGestures(gestures);
		}

		new TextExample();
	}

	private TextExample()
	{
		super("Gesture system demo");
		
		addWindowListener
		(
			new WindowAdapter() 
			{
				public void windowClosing(WindowEvent we) 
				{
					//Write out the current settings on exit
					File f = new File(DATA_FILE_NAME);
					
					if (!f.exists() || f.canWrite())
					{
						try
						{
							FileOutputStream fos = new FileOutputStream(f);
							GestureInterface.writeSettings(fos);
							fos.close();
						}
						catch (Exception e)
						{
							System.out.println("ERROR: couldn't write gesture settings: "+e);
							e.printStackTrace();
						}
					}

					System.exit(0); 
				}
			}
		);

		//Add the components to the frame
		setLayout(new BorderLayout());
		statusLabel.setText("Entered text: ");
		add(statusLabel,BorderLayout.SOUTH);

		Panel p = new Panel();
		p.add(settingsButton);
		p.add(editButton);
		add(p, BorderLayout.NORTH);

		setBounds(100, 100, getToolkit().getScreenSize().width - 200, getToolkit().getScreenSize().height - 200);
		setVisible(true);

		settingsButton.addActionListener(this);
		editButton.addActionListener(this);

		//This makes the GestureInterface listen for strokes on the frame
		GestureInterface.enableGestures(this);
		//This requests that the GestureInterface notify us when a gesture is made
		GestureInterface.addGestureListener(this);
	}

	/** Simple implementation of GestureListener */

	public void gesturePerformed(com.aleax.gui.gesture.Stroke stroke, int id)
	{
		lastStroke = stroke;

		statusLabel.setText(statusLabel.getText()+((char)id));
		repaint();
	}

	/** Overidden to show the last stroke made. */
	public void paint(Graphics g)
	{
		super.paint(g);

		if (lastStroke!=null)
		{
			g.setColor(Color.black);
			lastStroke.paint(g);
		}
	}

	public void actionPerformed(ActionEvent ae)
	{
		if (ae.getSource() == settingsButton)
		{
			GestureSettingsPanel.showDialog(this);
		}
		
		if (ae.getSource() == editButton)
		{
			GestureEditPanel.showDialog(this, null);
		}
	}
}